
<div align="left">
<img src="docs/assets/head_icon.png" alt="HEADER" width="150" align="left" hspace="15" vspace="0"/>

BEAMZ is an experimental **electromagnetic simulation** package using the FDTD method. It features a **high-level API** that enables fast prototyping and procedural design with just a few lines of code, made for (but not limited to) photonic integrated circuits.
</div>

```bash
pip3 install beamz
```
![PyPI](https://img.shields.io/pypi/v/beamz?color=0077be)
![Pre](https://img.shields.io/badge/pre--release-c40944)
